use strict;
use warnings;
package Rubric::CLI::Command::commands;
use base qw(App::Cmd::Command::commands);
our $VERSION = '0.149';

=head1 NAME

Rubric::CLI::Command::commands - list the rubric commands

=head1 VERSION

version 0.149

=cut

1;
